<header class="navbar">
    <a class="navbar-brand" href="{{ pathto(master_doc) }}">
        <img src="{{ pathto('_static' ~ theme_logo, 1) }}" alt="{{ theme_logo_alt }}">
    </a>

    <ul class="navbar-nav">
    {% if theme_navbar_dropdown %}
    {{theme_navbar_dropdown}}
    {% endif %}
    {% if theme_navbar_links %}
        {%- for link in theme_navbar_links %}<li><a href="{{ pathto(*link[1:]) }}">{{ link[0] }}</a></li>{%- endfor %}
    {% endif %}
    </ul>

    {% block navbarsearch %}
        {% include "navbarsearchbox.html" %}
    {% endblock %}
</header>