<div class="menu-btn" id="menu-btn">
  <p style="
    margin-left: auto;
    position: absolute;
    margin-top: 0;
    margin-bottom: 0;
">Local Table of Contents</p>
 <i id="closedMenu" class="fa fa-bars" aria-hidden="true"></i>
 <i id="openMenu" class="fa fa-times" aria-hidden="true"></i>
     </div>
  <div id="menu">
    {{ toc }}
  </div>

